@@ -19,12 +19,6 @@ test_that("Writing to incorrect path gives an error", {
 })
 
 
-test_that("Dataset needs at least one column", {
-  expect_error(fstwriteproxy(data.frame(), "bla.fst"), "Your dataset needs at least one column")
-})
-
-
-
 test_that("Columns need to be of type character", {
   fstwriteproxy(data.frame(A = 1:10), "testdata/bla.fst")
   expect_error(fstreadproxy("testdata/bla.fst", 2), "Parameter 'columns' should be a character vector of column names")
